tokenize

Function tokenize 

pub fn tokenize(sql: &str) -> Vec<SqlToken>
Simple SQL lexer that splits a SQL string into a token sequence.

This lexer does not depend on an external SQL parsing library; it only performs basic lexical splitting, for subsequent AST-level injection detection and complexity scoring.