pub fn validate_sql(sql: &str) -> ValidationResultExpand description
Validate any SQL statement by detecting its type and applying appropriate rules
pub fn validate_sql(sql: &str) -> ValidationResultValidate any SQL statement by detecting its type and applying appropriate rules